# Generated by Django 2.2.19 on 2021-08-12 09:06

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("engine", "0027_sendfailedcelerytask"),
    ]

    operations = [
        migrations.AlterField(
            model_name="pipelineprocess",
            name="parent_id",
            field=models.CharField(db_index=True, default="", max_length=32, verbose_name="父 process 的 ID"),
        ),
    ]
