# -*- coding: utf-8 -*-
# Generated by Django 1.11.29 on 2020-08-13 04:16
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("pipeline", "0024_auto_20200213_0738"),
    ]

    operations = [
        migrations.AlterField(
            model_name="snapshot",
            name="md5sum",
            field=models.CharField(db_index=True, max_length=32, verbose_name="快照字符串的md5sum"),
        ),
    ]
